PAWpySeed: WAVECAR_FILE Struct Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Attributes | List of all members
WAVECAR_FILE Struct Reference

`#include <reader.h>`

## Public Attributes
int | type
FILE * | fp
char * | start
char * | curr

## Member Data Documentation

char* WAVECAR_FILE::curr

FILE* WAVECAR_FILE::fp

char* WAVECAR_FILE::start

int WAVECAR_FILE::type

The documentation for this struct was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/core/reader.h